@@ -2,12 +2,10 @@ mod inlet_listener;
 mod outlet_listener;
 mod portal_message;
 mod portal_receiver;
-mod portal_sender;
-mod portal_worker_pair;
+mod portal_worker;
 
 pub(crate) use inlet_listener::*;
 pub(crate) use outlet_listener::*;
 pub(crate) use portal_message::*;
 pub(crate) use portal_receiver::*;
-pub(crate) use portal_sender::*;
-pub(crate) use portal_worker_pair::*;
+pub(crate) use portal_worker::*;
